package betterquesting.api2.registry;

import betterquesting.api2.registry.IFactory;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import javax.annotation.Nullable;
import net.minecraft.util.ResourceLocation;

/* loaded from: betterquesting_api2_registry.jar:betterquesting/api2/registry/SimpleRegistry.class */
public class SimpleRegistry<T extends IFactory<E>, E> implements IRegistry<T, E> {
    private final HashMap<ResourceLocation, T> factories = new HashMap<>();

    @Override // betterquesting.api2.registry.IRegistry
    public void register(T factory) {
        if (factory == null || factory.getRegistryName() == null) {
            throw new NullPointerException("Factory or registry name is null!");
        }
        if (this.factories.containsKey(factory.getRegistryName()) || this.factories.containsValue(factory)) {
            throw new IllegalArgumentException("Cannot register duplicate factory or registry name");
        }
        this.factories.put(factory.getRegistryName(), factory);
    }

    @Override // betterquesting.api2.registry.IRegistry
    @Nullable
    public T getFactory(ResourceLocation idName) {
        return this.factories.get(idName);
    }

    @Override // betterquesting.api2.registry.IRegistry
    @Nullable
    public E createNew(ResourceLocation idName) {
        IFactory<E> fact = getFactory(idName);
        if (fact == null) {
            return null;
        }
        return fact.createNew();
    }

    @Override // betterquesting.api2.registry.IRegistry
    public List<T> getAll() {
        return new ArrayList(this.factories.values());
    }
}
